pub fn extract_names_from_rotation(rotation: &Rotation) -> ReferencedNamesExpand description
Walks a parsed Rotation and collects every referenced name.
pub fn extract_names_from_rotation(rotation: &Rotation) -> ReferencedNamesWalks a parsed Rotation and collects every referenced name.