InterpretedRotation

Struct InterpretedRotation 

pub struct InterpretedRotation {
    rotation: Rotation,
    resolver: SpecResolver,
    schema: ContextSchema,
    table: DescriptorTable,
    sink: Option<DecisionTraceTarget>,
}
Interpreter backend (only choice on WASM; fallback on native without jit).

Fields

rotation: Rotationresolver: SpecResolverschema: ContextSchematable: DescriptorTablesink: Option<DecisionTraceTarget>

Implementations

Source

impl InterpretedRotation

pub fn from_parts( rotation: Rotation, resolver: SpecResolver, schema: ContextSchema, ) -> Self

Build an interpreter from an already-prepared ContextSchema.

pub fn compile_json(json: &str, resolver: &SpecResolver) -> Result<Self>

Parse JSON and compile.

Errors

Returns an error when parsing, validation, or lowering fails.

pub fn compile(rotation: &Rotation, resolver: &SpecResolver) -> Result<Self>

Compile an already-parsed rotation.

Errors

Returns an error when lowering or schema preparation fails.

pub fn set_sink(&mut self, sink: DecisionTraceTarget)

Attach a decision-trace sink.

pub fn has_sink(&self) -> bool

True when a sink is attached.

fn compile_inner(rotation: Rotation, resolver: &SpecResolver) -> Result<Self>